@@ -68,6 +68,24 @@ def close():
         _backend.close()
 
 
+def set_app_id(app_id):
+    """
+    设置app_id
+    :param app_id:
+    :return:
+    """
+    return _get_backend().set_app_id(app_id)
+
+
+def set_model_id(model_id):
+    """
+    设置model_id
+    :param model_id:
+    :return:
+    """
+    return _get_backend().set_app_id(model_id)
+
+
 def create_app(name, tags=[], desc=None):
     """
     创建应用
