@@ -15,7 +15,15 @@ import six
 
 
 @six.add_metaclass(ABCMeta)
-class Backend(object):
+class Backend:
+    model_id = None
+    app_id = None
+
+    def set_model_id(self, model_id):
+        self.model_id = model_id
+
+    def set_app_id(self, app_id):
+        self.app_id = app_id
 
     @abstractproperty
     def api_address(self):
