@@ -15,7 +15,7 @@ API_URL = 'WAVELETAI_API_URL'
 
 API_KEY = ''
 
-API_TOKEN = ''
+API_TOKEN = 'WAVELETAI_TOKEN'
 
 USER_NAME = 'WAVELETAI_USERNAME'
 
